@@ -21,10 +21,7 @@ from typing import Any
 
 from confluent_kafka.admin import AdminClient
 
-try:
-    from airflow.sdk import BaseHook
-except ImportError:
-    from airflow.hooks.base import BaseHook  # type: ignore[attr-defined,no-redef]
+from airflow.providers.common.compat.sdk import BaseHook
 
 
 class KafkaBaseHook(BaseHook):
